@@ -333,7 +333,8 @@ class SOCol(object):
     def sybaseCreateSQL(self):
         return ' '.join([self.dbName, self._sybaseType()] + self._extraSQL())
 
-    def mssqlCreateSQL(self):
+    def mssqlCreateSQL(self, connection=None):
+        self.connection = connection
         return ' '.join([self.dbName, self._mssqlType()] + self._extraSQL())
 
     def firebirdCreateSQL(self):
@@ -478,7 +479,10 @@ class SOStringLikeCol(SOCol):
         if self.customSQLType is not None:
             return self.customSQLType
         if not self.length:
-            type = 'varchar(4000)'
+            if self.connection and self.connection.can_use_max_types:
+                type = 'VARCHAR(MAX)'
+            else:
+                type = 'varchar(4000)'
         elif self.varchar:
             type = 'VARCHAR(%i)' % self.length
         else:
@@ -608,7 +612,7 @@ class SOIntCol(SOCol):
         if self.unsigned:
             _ret = _ret + " UNSIGNED"
         if self.zerofill:
-            _ret = _reg + " ZEROFILL"
+            _ret = _ret + " ZEROFILL"
         return _ret
 
     def _sqlType(self):
@@ -868,8 +872,8 @@ class SOForeignKey(SOKeyCol):
         # @@: Code from above should be moved here
         return None
 
-    def mssqlCreateSQL(self):
-        sql = SOKeyCol.mssqlCreateSQL(self)
+    def mssqlCreateSQL(self, connection=None):
+        sql = SOKeyCol.mssqlCreateSQL(self, connection)
         other = findClass(self.foreignKey, self.soClass.sqlmeta.registry)
         tName = other.sqlmeta.table
         idName = other.sqlmeta.idName
@@ -905,6 +909,21 @@ class ForeignKey(KeyCol):
     def __init__(self, foreignKey=None, **kw):
         super(ForeignKey, self).__init__(foreignKey=foreignKey, **kw)
 
+
+class EnumValidator(validators.Validator):
+
+    def to_python(self, value, state):
+        if value in self.enumValues:
+            return value
+        elif not self.notNone and value is None:
+            return None
+        else:
+            raise validators.Invalid("expected a member of %r in the EnumCol '%s', got %r instead" % \
+                                     (self.enumValues, self.name, value), value, state)
+
+    def from_python(self, value, state):
+        return self.to_python(value, state)
+
 class SOEnumCol(SOCol):
 
     def __init__(self, **kw):
@@ -963,20 +982,6 @@ class SOEnumCol(SOCol):
         else:
             return len(obj)
 
-class EnumValidator(validators.Validator):
-
-    def to_python(self, value, state):
-        if value in self.enumValues:
-            return value
-        elif not self.notNone and value is None:
-            return None
-        else:
-            raise validators.Invalid("expected a member of %r in the EnumCol '%s', got %r instead" % \
-                                     (self.enumValues, self.name, value), value, state)
-
-    def from_python(self, value, state):
-        return self.to_python(value, state)
-
 class EnumCol(Col):
     baseClass = SOEnumCol
 
@@ -1012,7 +1017,7 @@ class SOSetCol(SOCol):
             super(SOSetCol, self).createValidators()
 
     def _mysqlType(self):
-        return "SET(%s)" % ', '.join([sqlbuilder.sqlrepr(v, 'mysql') for v in self.enumValues])
+        return "SET(%s)" % ', '.join([sqlbuilder.sqlrepr(v, 'mysql') for v in self.setValues])
 
 class SetCol(Col):
     baseClass = SOSetCol
@@ -1404,7 +1409,10 @@ class SOBLOBCol(SOStringCol):
         return 'BYTEA'
 
     def _mssqlType(self):
-        return "IMAGE"
+        if self.connection and self.connection.can_use_max_types:
+            return 'VARBINARY(MAX)'
+        else:
+            return "IMAGE"
 
 class BLOBCol(StringCol):
     baseClass = SOBLOBCol
