@@ -5,8 +5,8 @@ from sqlobject.main import deprecated
 MySQLdb = None
 
 class ErrorMessage(str):
-    def __new__(cls, e, append_msg=''):
-        obj = str.__new__(cls, e[1] + append_msg)
+    def __new__(cls, e):
+        obj = str.__new__(cls, e[1])
         obj.code = int(e[0])
         obj.module = e.__module__
         obj.exception = e.__class__.__name__
@@ -32,24 +32,23 @@ class MySQLConnection(DBAPI):
         for key in ("unix_socket", "init_command",
                 "read_default_file", "read_default_group", "conv"):
             if key in kw:
-                self.kw[key] = col.popKey(kw, key)
+                self.kw[key] = kw.pop(key)
         for key in ("connect_timeout", "compress", "named_pipe", "use_unicode",
                 "client_flag", "local_infile"):
             if key in kw:
-                self.kw[key] = int(col.popKey(kw, key))
+                self.kw[key] = int(kw.pop(key))
+        for key in ("ssl_key", "ssl_cert", "ssl_ca", "ssl_capath"):
+            if key in kw:
+                if "ssl" not in self.kw:
+                    self.kw["ssl"] = {}
+                self.kw["ssl"][key[4:]] = kw.pop(key)
         if "charset" in kw:
-            self.dbEncoding = self.kw["charset"] = col.popKey(kw, "charset")
+            self.dbEncoding = self.kw["charset"] = kw.pop("charset")
         else:
             self.dbEncoding = None
         if "sqlobject_encoding" in kw:
             del kw["sqlobject_encoding"]
             deprecated("sqlobject_encoding is deprecated and no longer used.")
-
-        # MySQLdb < 1.2.1: only ascii
-        # MySQLdb = 1.2.1: only unicode
-        # MySQLdb > 1.2.1: both ascii and unicode
-        self.need_unicode = (MySQLdb.version_info[:3] >= (1, 2, 1)) and (MySQLdb.version_info[:3] < (1, 2, 2))
-
         DBAPI.__init__(self, **kw)
 
     def connectionFromURI(cls, uri):
@@ -73,8 +72,10 @@ class MySQLConnection(DBAPI):
             if MySQLdb.version_info[:3] >= (1, 2, 2):
                 conn.ping(True) # Attempt to reconnect. This setting is persistent.
         except self.module.OperationalError, e:
-            conninfo = "; used connection string: host=%(host)s, port=%(port)s, db=%(db)s, user=%(user)s" % self.__dict__
-            raise OperationalError(ErrorMessage(e, conninfo))
+            raise OperationalError(
+                "%s; used connection string: host=%s, port=%s, db=%s, user=%s, pwd=%s" % (
+                e, self.host, self.port, self.db, self.user, self.password)
+            )
 
         if hasattr(conn, 'autocommit'):
             conn.autocommit(bool(self.autoCommit))
@@ -93,12 +94,6 @@ class MySQLConnection(DBAPI):
             conn.autocommit(auto)
 
     def _executeRetry(self, conn, cursor, query):
-        if self.need_unicode and not isinstance(query, unicode):
-            try:
-                query = unicode(query, self.dbEncoding)
-            except UnicodeError:
-                pass
-
         # When a server connection is lost and a query is attempted, most of
         # the time the query will raise a SERVER_LOST exception, then at the
         # second attempt to execute it, the mysql lib will reconnect and
@@ -165,12 +160,13 @@ class MySQLConnection(DBAPI):
             self.printDebug(conn, id, 'QueryIns', 'result')
         return id
 
-    def _queryAddLimitOffset(self, query, start, end):
+    def _queryAddLimitOffset(cls, query, start, end):
         if not start:
             return "%s LIMIT %i" % (query, end)
         if not end:
             return "%s LIMIT %i, -1" % (query, start)
         return "%s LIMIT %i, %i" % (query, start, end-start)
+    _queryAddLimitOffset = classmethod(_queryAddLimitOffset)
 
     def createReferenceConstraint(self, soClass, col):
         return col.mysqlCreateReferenceConstraint()
@@ -214,7 +210,7 @@ class MySQLConnection(DBAPI):
                                 % tableName)
         results = []
         for field, t, nullAllowed, key, default, extra in colData:
-            if field == soClass.sqlmeta.idName:
+            if field == 'id':
                 continue
             colClass, kw = self.guessClass(t)
             if self.kw.get('use_unicode') and colClass is col.StringCol:
